==> ui-framework-elements-4.11.1-sources.jar: gen/displays/templates/MethodMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiTemplateStamp from "alexandria-ui-elements/src/displays/components/TemplateStamp";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import DisplaysMethodParamMold from "ui-elements/gen/displays/templates/MethodParamMold";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import MethodMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import MethodMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class MethodMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new MethodMoldNotifier(this);
		this.requester = new MethodMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1496800449" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1508597847" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1508597847.a_1020890974" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1508597847.a1051940149" format="h6" mode="normal" value="(">
					</UiText>
					<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1508597847.a_1766275619" multiple={{instances:"params",arrangement:"Vertical",noItemsMessage:"",spacing:0,editable:false,wrap:true,count:{min:0,max:-1}}}>
					</UiMultiple>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1508597847.a_227268250" format="h6" mode="normal" value=")">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1508597847.a1741819345" format="h6" mode="normal" value=":&nbsp;&nbsp;">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1508597847.a_1832521375" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1078061065" format="body2" mode="normal" value="">
				</UiText>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(MethodMold));
DisplayFactory.register("MethodMold", withStyles(styles, { withTheme: true })(withSnackbar(MethodMold)));

==> ui-framework-elements-4.12.9-sources.jar: gen/displays/templates/MethodMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiTemplateStamp from "alexandria-ui-elements/src/displays/components/TemplateStamp";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import DisplaysMethodParamMold from "ui-elements/gen/displays/templates/MethodParamMold";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import MethodMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import MethodMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class MethodMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new MethodMoldNotifier(this);
		this.requester = new MethodMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1496800449" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1981677617" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1981677617.a_1830237600" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1981677617.a_9068811" format="h6" mode="normal" value="(">
					</UiText>
					<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1981677617.a2135664667" multiple={{instances:"params",arrangement:"Vertical",noItemsMessage:"",spacing:0,editable:false,wrap:true,collapsed:false,count:{min:0,max:-1}}}>
					</UiMultiple>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1981677617.a_1288277210" format="h6" mode="normal" value=")">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1981677617.a220379870" format="h6" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1981677617.a1451328671" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1078061065" format="body2" mode="normal" value="">
				</UiText>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(MethodMold));
DisplayFactory.register("MethodMold", withStyles(styles, { withTheme: true })(withSnackbar(MethodMold)));
